0.9.9 API documentation: orthonormalize.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

orthonormalize.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependency:
17 #include "../vec3.hpp"
18 #include "../mat3x3.hpp"
19 #include "../geometric.hpp"
20
21 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
22 # ifndef GLM_ENABLE_EXPERIMENTAL
23 # pragma message("GLM: GLM_GTX_orthonormalize is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
24 # else
25 # pragma message("GLM: GLM_GTX_orthonormalize extension included")
26 # endif
27 #endif
28
29 namespace glm
30 {
33
37 template<typename T, qualifier Q>
38 GLM_FUNC_DECL mat<3, 3, T, Q> orthonormalize(mat<3, 3, T, Q> const& m);
39
43 template<typename T, qualifier Q>
44 GLM_FUNC_DECL vec<3, T, Q> orthonormalize(vec<3, T, Q> const& x, vec<3, T, Q> const& y);
45
47 }//namespace glm
48
49 #include "orthonormalize.inl"
glm::orthonormalize
GLM_FUNC_DECL vec< 3, T, Q > orthonormalize(vec< 3, T, Q > const &x, vec< 3, T, Q > const &y)
Orthonormalizes x according y.
glm
Definition: common.hpp:20